@@ -5,7 +5,7 @@ converting verse ids back into normalized references, and formatting
 references as human-readable strings.
 """
 
-__version__ = "0.6.1"
+__version__ = "0.7.1"
 
 from .bible.osis.parser import OSISParser
 from .book_groups import BOOK_GROUPS, BookGroup
@@ -47,7 +47,7 @@ from .verses import (
     get_book_chapter_verse,
     get_book_number,
     get_chapter_number,
-    get_max_number_of_verses,
+    get_number_of_verses,
     get_number_of_chapters,
     get_verse_id,
     get_verse_number,
